#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 optics-th
version:              0.4.1
visibility:           public
id:                   optics-th-0.4.1-G1Ny0rWsDDcI1PH1k8a79R
key:                  optics-th-0.4.1-G1Ny0rWsDDcI1PH1k8a79R
license:              BSD-3-Clause
maintainer:           optics@well-typed.com
author:               Andrzej Rybczak
synopsis:             Optics construction using TemplateHaskell
description:
    This package is part of the @<https://hackage.haskell.org/package/optics optics>@
    package family.  It provides machinery to construct optics using @TemplateHaskell@.

    See the @template-haskell-optics@ package for optics to work with @template-haskell@ types.

category:             Data, Optics, Lenses
abi:                  18f0aceb2f746009e4a43d7420b03d7f
exposed:              True
exposed-modules:
    Optics.TH Optics.TH.Internal.Product Optics.TH.Internal.Sum
    Optics.TH.Internal.Utils

hidden-modules:       Language.Haskell.TH.Optics.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/optics-th-0.4.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/optics-th-0.4.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/optics-th-0.4.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-optics-th
hs-libraries:         HSoptics-th-0.4.1-G1Ny0rWsDDcI1PH1k8a79R
depends:
    base-4.18.2.1 containers-0.6.7 mtl-2.3.1
    optics-core-0.4.2-Aksz8PRnmoL4plTZQxkU8c template-haskell-2.20.0.0
    th-abstraction-0.6.0.0-6nwiZFs5BlM71phLjoyZV3 transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-optics-th/html/optics-th.haddock
haddock-html:         /usr/share/doc/haskell-optics-th/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

